<?php

/*
	Plugin Name: Diagnostic Tool
	Plugin URI: http://mywwwsupport.com/plugin
	Description: Find common Email, Network and DNS setup problems & provides altered file montioring.
	Version: 1.0.2
	Author: IMRE Ltd
	Author URI: http://mywwwsupport.com

	The minimal amount of work to setup the plugin without being too obsurce.
*/

require_once('init.php');
require_once('lib/MWSSettings.class.php');
require_once('lib/MWSFileCheckSum.class.php');
require_once('lib/MWSOutboundConnection.class.php');
require_once('lib/MWSResolver.class.php');
require_once('views/menu.php');

/*
 * Debug hooks
 */
new MWSOutboundConnection();
$gMWSSettings = new MWSSettings();
$gMWSSettingsVals = $gMWSSettings->getSettings();

/*
 * Activate / Deactivate
 */
register_deactivation_hook(__FILE__, 'mwsDeactivate');
register_activation_hook(__FILE__, 'mwsActivate');

/*
 * Header, menu & cron hooks
 */
add_filter('admin_init', 'mwsCreateHeader');
add_filter('cron_schedules','custom_cron_schedules');

add_action('admin_menu', 'mwsCreateMenu');
add_action('mws_cron_hook', 'mwsRunCronJobs');

/*
 * AJAX callbacks
 */
add_action('wp_ajax_mws_http_check', array('MWSOutboundConnection', 'HTTPCheck'));
add_action('wp_ajax_mws_mail_check', array('MWSOutboundConnection', 'MailCheck'));
add_action('wp_ajax_mws_dns_check', array('MWSResolver', 'RunTest'));

function mwsActivate() {
    //wp_schedule_event(time(), 'hourly', 'mws_cron_hook');
    wp_schedule_event(time(), 'tenminutes', 'mws_cron_hook');
}

function custom_cron_schedules($schedules){
	$schedules['tenminutes'] = array(
		'interval'   => (10*60),
		'display'   => __('Ten minutes'),
	);

	return $schedules;
}

function mwsDeactivate() {
    delete_option('mws_filessum_opt');
    delete_option('mws_filessumlist_opt');
    wp_clear_scheduled_hook('mws_cron_hook');
}

function mwsCreateHeader() {
	wp_register_style('mwscss', plugins_url('css/mws.css', __FILE__));
	wp_enqueue_style('mwscss');
	wp_register_script('mwsjs', plugins_url('js/mws.js', __FILE__));
	wp_enqueue_script('mwsjs');
}

function mwsCreateMenu() {
	add_menu_page('mywwwsupport', 'Diagnostic Tool', 'administrator', 'mywwwsupportoverview', 'mwsOverviewPage');
	add_submenu_page('mywwwsupportoverview', 'Altered Files', 'Altered Files', 'administrator', MYWWWSUPPORTDIR.'views/mwsfilechecksumview.php');
	add_submenu_page('mywwwsupportoverview', 'Email Testing', 'Email Testing', 'administrator', MYWWWSUPPORTDIR.'views/mwsemailview.php');
	add_submenu_page('mywwwsupportoverview', 'Outbound Connections', 'Outbound Connections', 'administrator', MYWWWSUPPORTDIR.'views/mwsoutboundconnectionsview.php');
	add_submenu_page('mywwwsupportoverview', 'DNS Resolver', 'DNS Resolver', 'administrator', MYWWWSUPPORTDIR.'views/mwsresolverview.php');
	add_submenu_page('mywwwsupportoverview', 'Settings', 'Settings', 'administrator', MYWWWSUPPORTDIR.'views/mwssettings.php');
}

/*
 * Overview page
 */
function mwsOverviewPage() {
	global $wp_filter, $gMWSSettingsVals;

    echo '<div class="mwswrap">';
	mWSSubMenu();
    echo '<div class="mwsmainpage">';
	echo '<h2>Overview</h2>';
	echo '<h3>Welcome to the Diagnostic Tool by mywwwsupport.com</h3>';
	echo '<p>This plugin has been developed to help deal with common Wordpress issues. First you will get a description of the check or report that will be run, you can then choose to proceed if relevent. Please choose from the menu to the left of this text. Under <a href="'.MYWWWSUPPORTADMINPAGE.'views/mwssettings.php">settings</a> you can turn off parts of the plugin that you do not need.</p>';
	echo '<br/>Support: mywwwsupport.com</p>';

	echo '<h3>Module setup check</h3>';

	echo '<table class="wp-list-table">';
	echo '<thead>';
	echo '<tr>';
	echo '<th>Test</th>';
	echo '<th>Result</th>';
	echo '</tr>';
	echo '</thead>';
	echo '<tbody>';

	echo '<tr>';
	echo '<td>Cron job installed</td>';
	echo '<td>'.(($gMWSSettingsVals->cron_setup) ? 'Yes' : 'No').'</td>';
	echo '</tr>';

	echo '<tr>';
	echo '<td>Cron overdue</td>';
	echo '<td>'.(($gMWSSettingsVals->cron_overdue) ? 'Yes' : 'No').'</td>';
	echo '</tr>';

	echo '<tr>';
	echo '<td>Cron interval</td>';
	echo '<td>'.($gMWSSettingsVals->cron_interval).' seconds</td>';
	echo '</tr>';

	echo '<tr>';
	echo '<td>Cron next run</td>';
	echo '<td>'.($gMWSSettingsVals->cron_next_runtime).' seconds</td>';
	echo '</tr>';

	echo '</tbody>';
	echo '</table>';

	echo '</div>';
	echo '</div>';
}

/*
 * Cron
 */ 

function mwsRunCronJobs()
{
	global $gMWSSettingsVals; 

	/* File Checksum */
	if ($gMWSSettingsVals->disable_filesum_check != true)
	{
		$checksum = new MWSFileCheckSum();
		$checksum->runCron();
	}
	else
	{
		error_log('MWSFileCheckSum()->runCron() disabled');
	}
}
