<?php 

/*
	Plugin Name: Diagnostic Tool
	Plugin URI: http://mywwwsupport.com/plugin
	Description: Find common Email, Network and DNS setup problems & provides altered file montioring
	Revision: $Revision$
	Author: IMRE Ltd
	Author URI: http://mywwwsupport.com

*/

MWSEmailView::displayNotes();

class MWSEmailView {

	private $filesystem;

    function __construct() {
		$this->filesystem = new MWSFileCheckSum();
    }

	static function displayNotes()
	{
		global $wp_filter;

		$filesystem= new MWSFileCheckSum(); 

		?>

		<div class="mwswrap">
		<?php mWSSubMenu(); ?>
		<div class="mwsmainpage">
		<h2>Email Testing</h2>

		<h3>Mail test</h3>
		<p>By default Wordpress uses the builtin PHP mail() function. In Windows environments, this must be via an SMTP server. In Linux/Unix environments, this will be via Sendmail or equivalent. Alteratively you can use one of the SMTP plugins (http://wordpress.org/extend/plugins/) for WordPress.</p>

		<p><em>This will make 2 tests. 1 using the built in PHP method. The other will use the WordPress wp_mail() which may use a plugin, if you have one installed.</em></p>

		<p><em>Please check your inbox for 2 emails once you have run this test. If these 2 tests work, the ability for your blog to send emails is likely to work.</em></p>

		<form action="" id="mwsmailtest">
			<div id="mwsmailtestdiv" class="mws-test-line">
				<label>Email Address:</label>
				<input type="text" id="mwsmailtestemail" value="<?php echo get_bloginfo('admin_email', 'raw'); ?>" />
			</div>	
			<div class="mws-test-line">
				<label>mail() PHP builtin function:</label>
				<span id="mwsmailtestresult">Pending.....</span>
			</div>
			<div class="mws-test-line">
				<label>wp_mail() WordPress function:</label>
				<span id="mwswpmailtestresult">Pending.....</span>
			</div>
			<div class="mws-test-line-button">
				<a href="#" id="mwsmailtestsubmit" class="like-a-button">Run</a>
			</div>
		</form>

		<h4>Plugins (using Hooks) that alter the way email is sent in WordPress</h4>

		<pre><?php //var_dump($wp_filter['phpmailer_init']); ?></pre>

		<table class="wp-list-table widefat"><thead>
		<tr><th>WordPress Hook</th>
		<th>Function</th>
		<th>Plugin File</th>
		<th>Plugin Name</th>
		</tr></thead><tbody>

		<?php 
			$pluginsDir=ABSPATH.'wp-content/plugins/'; // TODO plugins dir is dynamic?
			$filesystem->listFolderFiles($pluginsDir);
			$files=$filesystem->getFiles();
			$found=false;
			foreach (array('phpmailer_init') as $searchHook)
			{
				if (!isset($wp_filter[$searchHook]))
					continue;

				$found=true;

				foreach ($wp_filter[$searchHook] as $hookkey => $hookArray)
				{
					foreach ($hookArray as $functionName => $functionValues)
					{

						$hookIsClass=false;
						if (gettype($functionValues['function']) == "string") {
							$searchFor = $functionName;
						} else {
							$rawName = print_r($functionValues['function'][0], true);
							$searchFor = substr($rawName, 0, strpos($rawName, ' Object'));
							$hookIsClass=true;
						}

						$pluginFile=false;
						foreach ($files as $filename => $md5) {
							if (strpos($filename, 'php') === false)
								continue;
							$contents = file_get_contents($filename);
							if (strpos($contents, $searchFor) !== false) {
								$pluginFile=$filename;
								break;
							}
						}
						reset($files);

						echo '<tr>';
						echo '<td>'.$searchHook.'</td>';
						echo '<td>'.(($hookIsClass)? ' Class ' : '').$searchFor.(($hookIsClass) ? '' : '()').'</td><td>';
			
						if ($pluginFile === false)
							echo 'File not found';
						else
							echo str_replace($pluginsDir, '', $filename);;

						$pluginData=get_plugin_data($filename);
						echo '</td><td>'.$pluginData['Name'].'</td></tr>';
					}

				}

			}

			if (!$found)
				echo '<tr><td colspan="4">No plugins altering wp_mail() call.</td></tr>';
			echo '</tbody></table>';
			
			if ($found)
				echo '<p><em>Please note plugins that alter the way WordPress sends emails have arbitrary settings. Please check the above plugin(s) are correctly configured. Your best bet is to check that the 2 tests above work.</em></p>';

		?>

		<h4>Plugins that send emails</h4>
		<table class="wp-list-table widefat"><thead>
		<tr><th>Mail Function</th>
		<th>Plugin File</th>
		<th>Plugin Name</th>
		</tr></thead><tbody>

		<?php

			$found=false;
			$pluginNames=array();
			$pluginOutput=array();
			foreach ($files as $filename => $md5) {
				if (strpos($filename, 'php') === false)
					continue;
				try
				{
					$contents = file_get_contents($filename);
				} catch (Exception $e) { 
					echo 'Failed to open file. '.$e->getMessage();	
					next;
				}

				$matches=array();
				$relFileName = str_replace($pluginsDir, '', $filename);
				preg_match('/\/([a-zA-Z0-9\-_]*)/', $relFileName, $matches);
				$pluginParentDir = $matches[1];

				//$dirBase=dirname[];

				if (strpos($contents, 'Plugin Name')) {
					$pluginData=get_plugin_data($filename);
					$pluginNames[$pluginParentDir]=$pluginData['Name']; 
				}
	
				foreach (array(' mail(', ' mail (', ' wp_mail(', ' wp_mail (') as $searchFunction)
				{
					if (strpos($contents, $searchFunction) !== false && strpos($filename, 'diagnostic-tool') === false)
					{
						$pluginLoc=str_replace($pluginsDir, '', $filename);
						$pluginOutput[] = array($searchFunction.')', $pluginLoc, $pluginParentDir);
						$found=true;
					}
				}
			}

			foreach ($pluginOutput as $key => $values)
			{
				echo '<tr>';
				echo '<td>'.$values[0].'</td>';
				echo '<td>'.$values[1].'</td>';
				echo '<td>'.@$pluginNames[$values[2]].'</td>';
				echo '</tr>';
			}

			if (!$found)
				echo '<tr><td colspan="3">No mail functions used within plugins</td></tr>';
		?>
		</tbody>
		</table>

		</div>
		</div>

		<div style="clear:both"></div>

		<?php
	}

}
